"""
Python module generated from Java source file org.bukkit.event.entity.FireworkExplodeEvent

Java source file obtained from artifact spigot-api version 1.20.5-R0.1-20240429.101539-37

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Firework
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class FireworkExplodeEvent(EntityEvent, Cancellable):
    """
    Called when a firework explodes.
    """

    def __init__(self, what: "Firework"):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        """
        Set the cancelled state of this event. If the firework explosion is
        cancelled, the firework will still be removed, but no particles will be
        displayed.

        Arguments
        - cancel: whether to cancel or not.
        """
        ...


    def getEntity(self) -> "Firework":
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.BubbleColumn

Java source file obtained from artifact spigot-api version 1.20.5-R0.1-20240429.101539-37

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import BlockData
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class BubbleColumn(BlockData):
    """
    'drag' indicates whether a force will be applied on entities moving through
    this block.
    """

    def isDrag(self) -> bool:
        """
        Gets the value of the 'drag' property.

        Returns
        - the 'drag' value
        """
        ...


    def setDrag(self, drag: bool) -> None:
        """
        Sets the value of the 'drag' property.

        Arguments
        - drag: the new 'drag' value
        """
        ...



from .PotionEffectTypeWrapper import PotionEffectTypeWrapper
from .PotionType import PotionType
from .PotionBrewer import PotionBrewer
from .PotionEffectType import PotionEffectType
from .PotionEffect import PotionEffect


"""
Python module generated from Java source file org.bukkit.block.data.type.Campfire

Java source file obtained from artifact spigot-api version 1.20.5-R0.1-20240429.101539-37

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import Directional
from org.bukkit.block.data import Lightable
from org.bukkit.block.data import Waterlogged
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class Campfire(Directional, Lightable, Waterlogged):
    """
    'signal_fire' denotes whether the fire is extra smokey due to having a hay
    bale placed beneath it.
    """

    def isSignalFire(self) -> bool:
        """
        Gets the value of the 'signal_fire' property.

        Returns
        - the 'signal_fire' value
        """
        ...


    def setSignalFire(self, signalFire: bool) -> None:
        """
        Sets the value of the 'signal_fire' property.

        Arguments
        - signalFire: the new 'signal_fire' value
        """
        ...



"""
Python module generated from Java source file org.bukkit.metadata.MetadataEvaluationException

Java source file obtained from artifact spigot-api version 1.20.5-R0.1-20240429.101539-37

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.metadata import *
from typing import Any, Callable, Iterable, Tuple


class MetadataEvaluationException(RuntimeException):
    """
    A MetadataEvaluationException is thrown any time a LazyMetadataValue fails to evaluate its value due to an exception. The
    originating exception will be included as this exception's cause.
    """


